<?php
/**
 * Piwik - free/libre analytics platform
 *
 * @link http://piwik.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 */

namespace Piwik\Plugins\TapatalkReport;
use Piwik\DataTable;
use Piwik\DataTable\Row;
use Piwik\Metrics;
/**
 * Class Archiver
 * @package Piwik\Plugins\TapatalkReport
 *
 * Archiver is class processing raw data into ready ro read reports.
 * It must implement two methods for aggregating daily reports
 * aggregateDayReport() and other for summing daily reports into periods
 * like week, month, year or custom range aggregateMultipleReports().
 *
 * For more detailed information about Archiver please visit Piwik developer guide
 * http://developer.piwik.org/api-reference/Piwik/Plugin/Archiver
 */
class Archiver extends \Piwik\Plugin\Archiver
{
    /**
     * It is a good practice to store your archive names (reports stored in database)
     * in Archiver class constants. You can define as many record names as you want
     * for your plugin.
     *
     * Also important thing is that record name must be prefixed with plugin name.
     *
     * This is only an example record name, so feel free to change it to suit your needs.
     */
    const ADS_REQUEST_DIMENSION     = "adsrequest";
    const ADS_REQUEST_RECORD_NAME   = 'TapatalkReport_adsrequest';
    const ADS_DISPLAY_DIMENSION     = "adsdisplay";
    const ADS_DISPLAY_RECORD_NAME   = 'TapatalkReport_adsdisplay';


    public function aggregateDayReport()
    {
        $table = $this->getLogAggregator()->getMetricsFromVisitByDimension(self::ADS_REQUEST_DIMENSION)->asDataTable();
        $value = array_sum($table->getColumn('label'));
        $this->getProcessor()->insertNumericRecord(self::ADS_REQUEST_RECORD_NAME, $value);

        $table = $this->getLogAggregator()->getMetricsFromVisitByDimension(self::ADS_DISPLAY_DIMENSION)->asDataTable();
        $value = array_sum($table->getColumn('label'));
        $this->getProcessor()->insertNumericRecord(self::ADS_DISPLAY_RECORD_NAME, $value);
    }

    public function aggregateMultipleReports()
    {
        $filedList = array(self::ADS_REQUEST_RECORD_NAME, self::ADS_DISPLAY_RECORD_NAME);
        $this->getProcessor()->aggregateNumericMetrics($filedList);
    }
}
